@@ -1,18 +1,7 @@
-import subprocess
-import yaml
 import arrow
-import json
-import pipes
-import re
-import traceback
 import sys
-import shutil
-import hashlib
-import os
-import tempfile
 import click
 import inquirer
-from datetime import datetime
 from .tools import remove_webassets
 from .tools import _askcontinue
 from .tools import get_volume_names
@@ -61,6 +50,7 @@ def do_list(config):
 @click.argument('name', required=False)
 @pass_config
 def snapshot_make(config, name):
+
     config.snapshot_manager.assert_environment(config)
     if not name:
         name = arrow.get().strftime("%Y%m%d")
@@ -110,6 +100,6 @@ def snapshot_clear_all(ctx, config):
     "volume is not used anymore, then its subvolumes are cleared."))
 @pass_config
 @click.pass_context
-def snapshots_purge_inactive_subvolumes(ctx, config):
+def snapshot_purge_inactive_subvolumes(ctx, config):
     config.snapshot_manager.assert_environment(config)
     config.snapshot_manager.purge_inactive(config)
